@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 # shortcuts
 #  os and distros
@@ -1107,7 +1107,7 @@ sub mapping {
      [cpanmod => 'Net::LibIDN',
       [os_freebsd,
        [package => 'libidn']],
-      [os => '~debian',
+      [like_debian,
        [package => 'libidn11-dev']]],
 
      [cpanmod => 'Net::NfDump',
@@ -1200,11 +1200,17 @@ sub mapping {
       [like_debian,
        [package => 'libvorbis-dev']]],
 
+     [cpanmod => 'Ogg::Vorbis::Header',
+      [os_freebsd,
+       [package => 'libogg']],
+      [like_debian,
+       [package => ['libogg-dev', 'libvorbis-dev']]]],
+
      [cpanmod => 'OpenGL',
       [os_freebsd,
        [package => 'freeglut']],
       [like_debian,
-       [package => ['freeglut3-dev', 'libxmu-dev']]]],
+       [package => ['freeglut3-dev', 'libxmu-dev', 'libxi-dev']]]],
 
      [cpanmod => 'OpenGL::FTGL',
       [like_debian,
